# Mechanical Transmission Analysis

[![PyPi](https://img.shields.io/pypi/v/gearpy)](https://pypi.org/project/gearpy/)
[![PyPi](https://img.shields.io/pypi/pyversions/gearpy.svg)](https://pypi.org/project/gearpy/)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://github.com/AndreaBlengino/gearpy/blob/v0.1.0/LICENSE)

[![Tests](https://github.com/AndreaBlengino/gearpy/actions/workflows/tests.yml/badge.svg?branch=master)](https://github.com/AndreaBlengino/gearpy/actions/workflows/tests.yml)
[![Documentation Status](https://readthedocs.org/projects/gearpy/badge/?version=latest)](https://gearpy.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/AndreaBlengino/gearpy/graph/badge.svg?token=4JHzii1LrK)](https://codecov.io/gh/AndreaBlengino/gearpy)

**gearpy** is a python package for mechanical transmission analysis.

## References

- [Source code](https://github.com/AndreaBlengino/gearpy/tree/master/gearpy)  
- [Issue tracker](https://github.com/AndreaBlengino/gearpy/issues)  
- [Documentation](https://gearpy.readthedocs.io/en/latest/?badge=latest)  
- [Installation](https://gearpy.readthedocs.io/en/latest/get_started.html)
- [Usage examples](https://gearpy.readthedocs.io/en/latest/examples/index.html)  
- [PyPI](https://pypi.org/project/gearpy/)  
- [GNU General Public License v3.0](https://github.com/AndreaBlengino/gearpy/blob/master/LICENSE)
